@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 # Copyright (c) 2012, 2014 Abhay Devasthale
 
@@ -9,6 +8,7 @@
 #   Adam Dybbroe <adam.dybbroe@smhi.se>
 #   Sara Hornquist <sara.hornquist@smhi.se>
 #   Martin Raspaud <martin.raspaud@smhi.se>
+#   Carlos Horn <carlos.horn@external.eumetsat.int>
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,12 +33,6 @@ import time
 import h5py
 import numpy as np
 
-try:
-    import ConfigParser
-except ImportError:
-    import configparser as ConfigParser
-
-from pygac import CONFIG_FILE
 from pygac.utils import slice_channel, strip_invalid_lat, check_user_scanlines
 
 LOG = logging.getLogger(__name__)
@@ -48,34 +42,6 @@ MISSING_DATA = -32001
 MISSING_DATA_LATLON = -999999
 
 
-def read_config():
-    """Read output dir etc from config file."""
-    if not os.path.exists(CONFIG_FILE) or not os.path.isfile(CONFIG_FILE):
-        raise IOError('{} pointed to by the environment variable '
-                      'PYGAC_CONFIG_FILE is not a file or does not exist!'
-                      .format(str(CONFIG_FILE)))
-
-    conf = ConfigParser.ConfigParser()
-    try:
-        conf.read(CONFIG_FILE)
-    except ConfigParser.NoSectionError:
-        LOG.exception('Failed reading configuration file: ' + str(CONFIG_FILE))
-        raise
-
-    options = {}
-    for option, value in conf.items('output', raw=True):
-        options[option] = value
-
-    OUTDIR = options['output_dir']
-    OUTPUT_FILE_PREFIX = options['output_file_prefix']
-
-    SUNSATANGLES_DIR = os.environ.get('SM_SUNSATANGLES_DIR', OUTDIR)
-    AVHRR_DIR = os.environ.get('SM_AVHRR_DIR', OUTDIR)
-    QUAL_DIR = os.environ.get('SM_AVHRR_DIR', OUTDIR)
-
-    return OUTPUT_FILE_PREFIX, SUNSATANGLES_DIR, AVHRR_DIR, QUAL_DIR
-
-
 def save_gac(satellite_name,
              xutcs,
              lats, lons,
@@ -83,7 +49,8 @@ def save_gac(satellite_name,
              bt3, bt4, bt5,
              sun_zen, sat_zen, sun_azi, sat_azi, rel_azi,
              qual_flags, start_line, end_line,
-             gac_file, meta_data):
+             gac_file, meta_data,
+             output_file_prefix, avhrr_dir, qual_dir, sunsatangles_dir):
 
     midnight_scanline = meta_data['midnight_scanline']
     miss_lines = meta_data['missing_scanlines']
@@ -226,7 +193,7 @@ def save_gac(satellite_name,
                 sun_zen, sat_zen, sun_azi, sat_azi, rel_azi, qual_flags,
                 start_line, end_line, total_number_of_scan_lines,
                 last_scan_line_number, corr, gac_file, midnight_scanline,
-                miss_lines)
+                miss_lines, output_file_prefix, avhrr_dir, qual_dir, sunsatangles_dir)
 
 
 def avhrrGAC_io(satellite_name, xutcs, startdate, enddate, starttime, endtime,
@@ -234,11 +201,7 @@ def avhrrGAC_io(satellite_name, xutcs, startdate, enddate, starttime, endtime,
                 arrSZA, arrSTZ, arrSAA, arrSTA, arrRAA, qual_flags,
                 start_line, end_line, total_number_of_scan_lines,
                 last_scan_line_number, corr, gac_file, midnight_scanline,
-                miss_lines):
-    import os
-
-    # Read output dir etc from config file
-    OUTPUT_FILE_PREFIX, SUNSATANGLES_DIR, AVHRR_DIR, QUAL_DIR = read_config()
+                miss_lines, output_file_prefix, avhrr_dir, qual_dir, sunsatangles_dir):
 
     # Calculate start and end time in sec1970
     t_obj = time.strptime(startdate + starttime[0:6], "%Y%m%d%H%M%S")
@@ -246,9 +209,9 @@ def avhrrGAC_io(satellite_name, xutcs, startdate, enddate, starttime, endtime,
     t_obj = time.strptime(enddate + endtime[0:6], "%Y%m%d%H%M%S")
     endtime_sec1970 = calendar.timegm(t_obj)
 
-    LOG.info('Output file prefix = ' + str(OUTPUT_FILE_PREFIX))
-    LOG.info('AVHRR data will be written to ' + str(AVHRR_DIR))
-    ofn = os.path.join(AVHRR_DIR, (OUTPUT_FILE_PREFIX + '_avhrr_' +
+    LOG.info('Output file prefix = ' + str(output_file_prefix))
+    LOG.info('AVHRR data will be written to ' + str(avhrr_dir))
+    ofn = os.path.join(avhrr_dir, (output_file_prefix + '_avhrr_' +
                                    satellite_name + '_99999_' +
                                    startdate + 'T' + starttime + 'Z_' +
                                    enddate + 'T' + endtime + 'Z.h5'))
@@ -457,9 +420,9 @@ def avhrrGAC_io(satellite_name, xutcs, startdate, enddate, starttime, endtime,
     fout.close()
 
     LOG.info('Sun and Satellite viewing angles will be ' +
-             'written to ' + str(SUNSATANGLES_DIR))
-    ofn = os.path.join(SUNSATANGLES_DIR,
-                       (OUTPUT_FILE_PREFIX + '_sunsatangles_' +
+             'written to ' + str(sunsatangles_dir))
+    ofn = os.path.join(sunsatangles_dir,
+                       (output_file_prefix + '_sunsatangles_' +
                         satellite_name + '_99999_' + startdate +
                         'T' + starttime + 'Z_' +
                         enddate + 'T' + endtime + 'Z.h5'))
@@ -556,7 +519,7 @@ def avhrrGAC_io(satellite_name, xutcs, startdate, enddate, starttime, endtime,
     g4.attrs["dataset_name"] = np.string_('Solar azimuth angle')
     g4.attrs["units"] = np.string_('Deg')
     g4.attrs["gain"] = np.float32(0.01)
-    g4.attrs["offset"] = np.float32(180.0)
+    g4.attrs["offset"] = np.float32(0.0)
     g4.attrs["missingdata"] = np.int32(MISSING_DATA)
     g4.attrs["nodata"] = np.int32(MISSING_DATA)
     g4.attrs["starttime"] = np.string_(starttime[0:6])
@@ -569,7 +532,7 @@ def avhrrGAC_io(satellite_name, xutcs, startdate, enddate, starttime, endtime,
     g5.attrs["dataset_name"] = np.string_('Satellite azimuth angle')
     g5.attrs["units"] = np.string_('Deg')
     g5.attrs["gain"] = np.float32(0.01)
-    g5.attrs["offset"] = np.float32(180.0)
+    g5.attrs["offset"] = np.float32(0.0)
     g5.attrs["missingdata"] = np.int32(MISSING_DATA)
     g5.attrs["nodata"] = np.int32(MISSING_DATA)
     g5.attrs["starttime"] = np.string_(starttime[0:6])
@@ -621,9 +584,9 @@ def avhrrGAC_io(satellite_name, xutcs, startdate, enddate, starttime, endtime,
     fout.close()
 
     LOG.info('Quality flags will be ' +
-             'written to ' + str(QUAL_DIR))
-    ofn = os.path.join(QUAL_DIR,
-                       (OUTPUT_FILE_PREFIX + '_qualflags_' +
+             'written to ' + str(qual_dir))
+    ofn = os.path.join(qual_dir,
+                       (output_file_prefix + '_qualflags_' +
                         satellite_name + '_99999_' + startdate +
                         'T' + starttime + 'Z_' +
                         enddate + 'T' + endtime + 'Z.h5'))
