@@ -24,9 +24,10 @@
 
 Can't be used as is, has to be subclassed to add specific read functions.
 """
-from abc import ABCMeta, abstractmethod, abstractproperty
+from abc import ABCMeta, abstractmethod
 import datetime
 import logging
+
 import numpy as np
 import os
 import re
@@ -49,34 +50,35 @@ LOG = logging.getLogger(__name__)
 # rpy values from
 # here:http://yyy.rsmas.miami.edu/groups/rrsl/pathfinder/Processing/proc_app_a.html
 rpy_coeffs = {
-    'noaa7':  {'roll':  0.000,
+    'noaa7': {'roll': 0.000,
+              'pitch': 0.000,
+              'yaw': 0.000,
+              },
+    'noaa9': {'roll': 0.000,
+              'pitch': 0.0025,
+              'yaw': 0.000,
+              },
+    'noaa10': {'roll': 0.000,
                'pitch': 0.000,
-               'yaw':   0.000,
-               },
-    'noaa9':  {'roll':  0.000,
-               'pitch': 0.0025,
-               'yaw':   0.000,
-               },
-    'noaa10': {'roll':  0.000,
-               'pitch': 0.000,
-               'yaw':   0.000,
+               'yaw': 0.000,
                },
     'noaa11': {'roll': -0.0019,
                'pitch': -0.0037,
-               'yaw':   0.000,
+               'yaw': 0.000,
                },
-    'noaa12': {'roll':  0.000,
+    'noaa12': {'roll': 0.000,
                'pitch': 0.000,
-               'yaw':   0.000,
+               'yaw': 0.000,
                },
-    'noaa14': {'roll':  0.000,
+    'noaa14': {'roll': 0.000,
                'pitch': 0.000,
-               'yaw':   0.000,
+               'yaw': 0.000,
                }}
 
 
 class ReaderError(ValueError):
-    """Raised in Reader.read if the given file does not correspond to it"""
+    """Raised in Reader.read if the given file does not correspond to it."""
+
     pass
 
 
@@ -134,7 +136,7 @@ class Reader(six.with_metaclass(ABCMeta)):
 
     @property
     def times(self):
-        """The UTCs as datetime.datetime"""
+        """Get the UTCs as datetime.datetime."""
         return self.to_datetime(self.utcs)
 
     @property
@@ -196,7 +198,7 @@ class Reader(six.with_metaclass(ABCMeta)):
 
     @classmethod
     def _correct_data_set_name(cls, header, filename):
-        """Replace invalid data_set_name from header with filename
+        """Replace invalid data_set_name from header with filename.
 
         Args:
             header (struct): file header
@@ -221,7 +223,7 @@ class Reader(six.with_metaclass(ABCMeta)):
 
     @classmethod
     def _validate_header(cls, header):
-        """Check if the header belongs to this reader
+        """Check if the header belongs to this reader.
 
         Note:
             according to https://www1.ncdc.noaa.gov/pub/data/satellite/
@@ -258,7 +260,7 @@ class Reader(six.with_metaclass(ABCMeta)):
                               % header['data_set_name'])
 
     def _read_scanlines(self, buffer, count):
-        """Read the scanlines from the given buffer
+        """Read the scanlines from the given buffer.
 
         Args:
             buffer (bytes, bytearray): buffer to read from
@@ -304,7 +306,7 @@ class Reader(six.with_metaclass(ABCMeta)):
 
     @classmethod
     def fromfile(cls, filename, fileobj=None):
-        """Create Reader from file (alternative constructor)
+        """Create Reader from file, alternative constructor.
 
         Args:
             filename (str): Path to GAC/LAC file
@@ -323,14 +325,14 @@ class Reader(six.with_metaclass(ABCMeta)):
         return instance
 
     def _get_calibrated_channels_uniform_shape(self):
-        """Prepare the channels as input for gac_io.save_gac"""
+        """Prepare the channels as input for gac_io.save_gac."""
         channels = self.get_calibrated_channels()
         assert channels.shape[-1] == 6
         return channels
 
     def save(self, start_line, end_line, output_file_prefix="PyGAC", output_dir="./",
              avhrr_dir=None, qual_dir=None, sunsatangles_dir=None):
-        """Convert the Reader instance content into hdf5 files"""
+        """Convert the Reader instance content into hdf5 files."""
         avhrr_dir = avhrr_dir or output_dir
         qual_dir = qual_dir or output_dir
         sunsatangles_dir = sunsatangles_dir or output_dir
@@ -521,7 +523,10 @@ class Reader(six.with_metaclass(ABCMeta)):
             corr
         )
         prt, ict, space = self.get_telemetry()
-        for chan in [3, 4, 5]:
+
+        ir_channels_to_calibrate = self._get_ir_channels_to_calibrate()
+
+        for chan in ir_channels_to_calibrate:
             channels[:, :, chan - 6] = calibrate_thermal(
                 channels[:, :, chan - 6],
                 prt,
@@ -590,12 +595,14 @@ class Reader(six.with_metaclass(ABCMeta)):
             self._mask = self._get_corrupt_mask()
         return self._mask
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def QFlag(self):  # pragma: no cover
         """KLM/POD specific quality indicators."""
         raise NotImplementedError
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def _quality_indicators_key(self):  # pragma: no cover
         raise NotImplementedError
 
@@ -775,16 +782,15 @@ class Reader(six.with_metaclass(ABCMeta)):
         and different ranges.
 
         Returns:
-
             sat_azi: satellite azimuth angle degree clockwise from north in
             range ]-180, 180]
 
-            sat_zentih: satellite zenith angles in degrees in range [0,90]
+            sat_zenith: satellite zenith angles in degrees in range [0,90]
 
             sun_azi: sun azimuth angle degree clockwise from north in range
             ]-180, 180]
 
-            sun_zentih: sun zenith angles in degrees in range [0,90]
+            sun_zenith: sun zenith angles in degrees in range [0,90]
 
             rel_azi: absolute azimuth angle difference in degrees between sun
             and sensor in range [0, 180]
@@ -876,7 +882,7 @@ class Reader(six.with_metaclass(ABCMeta)):
         """Remove scanlines with corrupted scanline numbers.
 
         This includes:
-            - Scanline numbers outside the valide range
+            - Scanline numbers outside the valid range
             - Scanline numbers deviating more than a certain threshold from the
               ideal case (1,2,3,...N)
 
@@ -894,7 +900,7 @@ class Reader(six.with_metaclass(ABCMeta)):
                    'n_orig': self.scans['scan_line_number'].copy()}
 
         # Remove scanlines whose scanline number is outside the valid range
-        within_range = np.logical_and(self.scans["scan_line_number"] < 15000,
+        within_range = np.logical_and(self.scans["scan_line_number"] < self.max_scanlines,
                                       self.scans["scan_line_number"] >= 0)
         self.scans = self.scans[within_range]
 
@@ -927,7 +933,7 @@ class Reader(six.with_metaclass(ABCMeta)):
                 # Relatively small variation, keep (almost) everything
                 thresh = mean_nz_diffs + 3*std_nz_diffs
             else:
-                # Large variation, filter more agressively. Use median and
+                # Large variation, filter more aggressively. Use median and
                 # median absolute deviation (MAD) as they are less sensitive to
                 # outliers. However, allow differences < 500 scanlines as they
                 # occur quite often.
@@ -1049,7 +1055,8 @@ class Reader(six.with_metaclass(ABCMeta)):
         results.update({'tn': tn, 'tcorr': self.utcs, 't0': t0})
         return results
 
-    @abstractproperty
+    @property
+    @abstractmethod
     def tsm_affected_intervals(self):  # pragma: no cover
         """Specify time intervals being affected by the scan motor problem.
 
@@ -1131,7 +1138,7 @@ class Reader(six.with_metaclass(ABCMeta)):
         raise NotImplementedError
 
     def get_attitude_coeffs(self):
-        """Return the roll, pitch, yaw values"""
+        """Return the roll, pitch, yaw values."""
         if self._rpy is None:
             if "constant_yaw_attitude_error" in self.head.dtype.fields:
                 rpy = np.deg2rad([self.head["constant_roll_attitude_error"] / 1e3,
